@@ -23,8 +23,10 @@
 Create.actor.reddit <- function(datasource, type, ...) {
   cat("Generating reddit actor network...")
   
-  df <- tibble::as_tibble(datasource) 
-
+  # df <- tibble::as_tibble(datasource) 
+  # df <- datasource 
+  class(datasource) <- rmCustCls(class(datasource))
+  
   # df_thread <- datasource
 
   # actor_network <- RedditExtractoR::user_network(df_thread, include_author = TRUE, agg = FALSE)
@@ -34,7 +36,7 @@ Create.actor.reddit <- function(datasource, type, ...) {
   # include_author <- TRUE
 
   # select cols and rename id and user
-  df_relations <- df %>% 
+  df_relations <- datasource %>% 
     dplyr::select(.data$id, .data$subreddit, .data$thread_id, .data$comm_id, .data$structure,
                   .data$user, .data$author) %>% 
     dplyr::rename("comment_id" = .data$id, "sender" = .data$user)
@@ -48,7 +50,7 @@ Create.actor.reddit <- function(datasource, type, ...) {
     # rename structure to response_to and user to receiver
     # left join df_relations to response_to, receiver by response_to
     # FIXED: crossing threads by joining only on structure (response_to)
-    dplyr::left_join(df %>% 
+    dplyr::left_join(datasource %>% 
       dplyr::select(.data$thread_id, .data$structure, .data$user) %>%
       dplyr::rename("response_to" = .data$structure, "receiver" = .data$user), by = c("response_to", "thread_id"))
 
@@ -68,7 +70,7 @@ Create.actor.reddit <- function(datasource, type, ...) {
     dplyr::select(.data$sender, .data$receiver, .data$comment_id, .data$subreddit, .data$comm_id, .data$thread_id)
 
   # attempt to add authors thread posts as self-loops
-  authors <- dplyr::select(df, .data$subreddit, .data$thread_id, .data$author) %>% dplyr::distinct() %>%
+  authors <- dplyr::select(datasource, .data$subreddit, .data$thread_id, .data$author) %>% dplyr::distinct() %>%
     dplyr::mutate(sender = .data$author, receiver = .data$author, comment_id = 0, author = NULL)
   
   df_relations <- dplyr::bind_rows(df_relations, authors)
