@@ -2,14 +2,18 @@
 #' 
 #' @description Creates a semantic network from tweets returned from the twitter search query. Semantic networks 
 #' describe the semantic relationships between concepts. In this network the concepts are significant words and 
-#' hashtags extracted from the tweet text. Network edges are weighted and represent occurence of words and
+#' hashtags extracted from the tweet text. Network edges are weighted and represent occurrence of words and
 #' hashtags in the same tweets.
 #' 
+#' The creation of twitter semantic networks requires text processing and the tokenization of tweets. As such
+#' this function requires the additional installation of the \pkg{tidyr} and \pkg{tidytext} packages to achieve
+#' this.
+#' 
 #' @note The words and hashtags passed to the function in the \code{removeTermsOrHashtags} parameter are removed
 #' before word frequencies are calculated and are therefore excluded from top percentage of most frequent terms
 #' completely rather than simply filtered out of the final network.
 #' 
-#' The top percentage of frequently occuring hashtags \code{hashtagFreq} and words \code{termFreq} are calculated to a
+#' The top percentage of frequently occurring hashtags \code{hashtagFreq} and words \code{termFreq} are calculated to a
 #' minimum frequency and all terms that have an equal or greater frequency than the minimum are included in the network
 #' as nodes. For example, of unique hashtags of varying frequencies in a dataset the top 50% of total
 #' frequency or most common hashtags may calculate to being the first 20 hashtags. The frequency of the 20th hashtag is
@@ -51,6 +55,10 @@
 #' 
 #' @examples
 #' \dontrun{
+#' # twitter semantic network creation additionally requires the tidyr, tidytext and stopwords packages
+#' # for working with text data
+#' install.packages(c("tidyr", "tidytext", "stopwords"))
+#' 
 #' # create a twitter semantic network graph removing the hashtag '#auspol' and using the
 #' # top 2% frequently occurring words and 10% most frequently occurring hashtags as nodes
 #' semanticNetwork <- twitterData %>% 
@@ -99,6 +107,9 @@ Create.semantic.twitter <- function(datasource, type, removeTermsOrHashtags = NU
   
   if (verbose) { df_stats <- networkStats(NULL, "collected tweets", nrow(datasource)) }
   
+  # datasource <- tibble::as_tibble(datasource)
+  class(datasource) <- rmCustCls(class(datasource))
+  
   datasource <- datasource %>% dplyr::select(.data$status_id, .data$text, .data$hashtags)
   datasource$text = HTMLdecode(datasource$text)
   
@@ -249,7 +260,7 @@ Create.semantic.twitter <- function(datasource, type, removeTermsOrHashtags = NU
     "edges" = edges
   )
   
-  class(func_output) <- union(class(func_output), c("network", "semantic", "twitter"))
+  class(func_output) <- append(class(func_output), c("network", "semantic", "twitter"))
   cat("Done.\n")
   
   func_output
